@@ -12,13 +12,12 @@ logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(level
 log = logging.getLogger(__name__)
 
 
-sys.argv =[sys.argv[0],'C://Users/zhangfan36/Desktop/简历/证件照.jpg']
-def main():
+def main(file='C://Users/zhangfan36/Desktop/简历/证件照.jpg'):
     # 准备好必要参数
     beautiful_url='https://api-cn.faceplusplus.com/facepp/v2/beautify'
     api_key='kTseH9TtSH_Hody8k15fhkRzyXpEuhmJ'
     api_secret='9kNy0Utc-mIDTtnvwVWuzHv3uQgIdscZ'
-    with open(sys.argv[1],'rb') as f:
+    with open(file,'rb') as f:
         image_base64=base64.b64encode(f.read())
 
     data={
